@@ -13,33 +13,13 @@
 #'         times as individuals in \code{database}. If the element is a vector, its length will be changed to the number of individuals. If the element is
 #'         a matrix, then its first dimension will be changed to the number of individuals, while keeping the size of the second dimension. If the element 
 #'         is a cube, then only the first dimension's length is changed, preserving the others.
-#' @examples 
-#' database <- data.frame(ID=rep(1:5, each=3), apollo_sequence=rep(1:3, 5))
-#' apollo_inputs <- list(database=database)
-#' attach(database)
-#' 
-#' P0 <- 0.5
-#' apollo_firstRow(P0, apollo_inputs) 
-#' 
-#' P1 <- rep(c(0.1, 0.2, 0.3, 0.4, 0.5), each=3)
-#' apollo_firstRow(P1, apollo_inputs) 
-#' 
-#' P2 <- matrix(rep(P1,10), nrow=15, ncol=10)
-#' apollo_firstRow(P2, apollo_inputs) 
-#' 
-#' P3 <- array(rep(P1, 10*10), dim=c(15, 10, 10))
-#' apollo_firstRow(P3, apollo_inputs)
-#' 
-#' P4 <- list(P0, P1, P2, P3)
-#' apollo_firstRow(P4, apollo_inputs)
 #' @export
 apollo_firstRow=function(P, apollo_inputs){
   apollo_sequence <- apollo_inputs$database$apollo_sequence
   
   ### If P is a list
   if(is.list(P)){
-    j=1
-    while(j<=length(P)){
+    for(j in 1:length(P)){
       isSca <- length(P[[j]])==1
       isVec <- is.vector(P[[j]]) && !isSca
       isMat <- is.matrix(P[[j]])
@@ -47,7 +27,6 @@ apollo_firstRow=function(P, apollo_inputs){
       if(isSca) P[[j]] = rep(P[[j]], sum(apollo_sequence==1))
       if(isVec|isMat) P[[j]] = subset(P[[j]],apollo_sequence==1)
       if(isCub) P[[j]] = P[[j]][(apollo_sequence==1),,,drop=FALSE]
-      j=j+1
     }
     ### If P is a data.frame (besides being a list)
     if(is.data.frame(P)) P <- P[1:sum(apollo_sequence==1),]
